package com.hx.utils.application.ui.web

import android.os.Bundle
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.LinearLayout
import androidx.appcompat.app.AlertDialog
import androidx.appcompat.app.AppCompatActivity
import androidx.fragment.app.Fragment
import androidx.lifecycle.ViewModelProvider
import com.hx.utils.application.base.BaseWebView
import com.hx.utils.application.databinding.FragmentWebBinding

class WebFragment : Fragment() {
    private var _binding: FragmentWebBinding? = null
    private var webView: BaseWebView? = null
    private val binding get() = _binding!!
    private lateinit var webViewModel: WebViewModel
    override fun onCreateView(
        inflater: LayoutInflater,
        container: ViewGroup?,
        savedInstanceState: Bundle?
    ): View {
        _binding = FragmentWebBinding.inflate(inflater, container, false)
        val root: View = binding.root
        webViewModel = ViewModelProvider(this)[WebViewModel::class.java]

        webViewModel.urlFormState.observe(viewLifecycleOwner) {
            binding.fab.show()
            binding.loading.visibility = View.GONE
            if (it.success == true)
                successTip()
            else
                errorTip()

        }
        webView?.loadUrl("初始默认地址") ?: run {
            webView = BaseWebView(requireActivity()).apply {
                loadUrl("初始默认地址")
            }
            binding.mainWeb.addView(
                webView, LinearLayout.LayoutParams(
                    LinearLayout.LayoutParams.MATCH_PARENT,
                    LinearLayout.LayoutParams.MATCH_PARENT
                )
            )
        }
        binding.fab.setOnClickListener {
            binding.fab.hide()
            binding.loading.visibility = View.VISIBLE
            webViewModel.startListening()
        }
        (activity as? AppCompatActivity)?.supportActionBar?.title = arguments?.getString("data")
        return root
    }

    override fun onDestroyView() {
        super.onDestroyView()
        _binding = null
    }

    private fun successTip() {
        val dialog = AlertDialog.Builder(requireActivity())
            .setTitle("WebTestBot Message")
            .setMessage(
                "URL: ${webViewModel.urlFormState.value!!.url}\nName: ${webViewModel.urlFormState.value!!.username}\nFirst Name: ${webViewModel.urlFormState.value!!.firstName}"
            )
            .setPositiveButton("Go") { dialogInterface, _ ->
                webView?.loadUrl(webViewModel.urlFormState.value!!.url)
                dialogInterface.dismiss()
            }
            .setNegativeButton("Cancel") { dialogInterface, _ ->
                dialogInterface.dismiss()
            }
            .create()
        dialog.show()
    }

    private fun errorTip() {
        val dialog = AlertDialog.Builder(requireActivity())
            .setTitle("Error Info")
            .setMessage(
                webViewModel.urlFormState.value!!.error
            )
            .setPositiveButton("Ok") { dialogInterface, _ ->
                webView?.loadUrl(webViewModel.urlFormState.value!!.url)
                dialogInterface.dismiss()
            }
            .create()
        dialog.show()
    }
}